@@ -62,7 +62,8 @@ if sys.version_info.major > 2:
     tostr = lambda lts: lts.decode()
 else:
     tostr = lambda lts: lts
-    unicode = unicode  # due to above unicode entry in __all__
+    # due to above unicode entry in __all__
+    unicode = unicode  #noqa: PLW0127
 try:
     import ssl
 except ImportError:
@@ -245,7 +246,7 @@ def alarm_handler(*unused):
 def is_maildir(d):
     '''Verify a path is a maildir.
     '''
-    dir_parent = os.path.dirname(d.endswith('/') and d[:-1] or d)
+    dir_parent = os.path.dirname(d.endswith('/') and d[:-1] or d) or '.'
     if not os.access(dir_parent, os.X_OK):
         raise getmailConfigurationError(
             'cannot read contents of parent directory of %s '
@@ -286,7 +287,7 @@ def deliver_maildir(maildirpath, data, hostname, dcount=None, filemode=0o600):
 
     info = {
         'deliverycount' : dcount,
-        'hostname' : hostname.split('.')[0].replace('/', '\\057').replace(
+        'hostname' : hostname.replace('/', '\\057').replace(
             ':', '\\072'),
         'pid' : os.getpid(),
     }
@@ -532,8 +533,7 @@ def check_ca_certs(conf):
         ca_certs = expand_user_vars(ca_certs)
         if ssl is None:
             raise getmailConfigurationError(
-                'specifying ca_certs not supported by this installation of '
-                'Python; requires Python 2.6'
+                'specifying ca_certs not supported by this Python'
             )
     if ca_certs and not os.path.isfile(ca_certs):
         raise getmailConfigurationError(
@@ -548,8 +548,7 @@ def check_ssl_version(conf):
         return None
     if ssl is None:
         raise getmailConfigurationError(
-            'specifying ssl_version not supported by this installation of '
-            'Python; requires Python 2.6'
+            'specifying ssl_version not supported by this Python'
         )
     def get_or_fail(version, symbol):
         if symbol is not None:
@@ -580,8 +579,7 @@ def check_ssl_fingerprints(conf):
         return ()
     if ssl is None or hashlib is None:
         raise getmailConfigurationError(
-            'specifying ssl_fingerprints not supported by this installation of '
-            'Python; requires Python 2.6'
+            'specifying ssl_fingerprints not supported by this Python'
         )
 
     normalized_fprs = []
@@ -600,8 +598,7 @@ def check_ssl_ciphers(conf):
     if ssl_ciphers:
         if sys.version_info < (2, 7, 0):
             raise getmailConfigurationError(
-                'specifying ssl_ciphers not supported by this installation of '
-                'Python; requires Python 2.7'
+                'specifying ssl_ciphers not supported by this Python'
             )
         if re.search(r'[^a-zA-z0-9, :!\-+@=]', ssl_ciphers):
             raise getmailConfigurationError(
